@@ -132,13 +132,16 @@ class Labeler:
             progress_label.value = f"{file_index+1} / {len(files)}"
 
         def on_add_class(b):
-            new_class = input("class name")
-            print(new_class)
+            if new_class_text.value.strip() != '':
+              class_list = list(w_bbox.classes)
+              class_list.append(new_class_text.value)
+              w_bbox.classes = list(set(class_list))
+              new_class_text.value = ""
 
         def on_predict(b):
             global file_index
-
             image_file = file_paths[file_index]
+
             result = yolo_model(image_file)
             result = result.pandas().xyxy[0] 
             result["width"] = result.xmax - result.xmin
@@ -151,7 +154,6 @@ class Labeler:
             #Add the predicted classes to the widget so they can be selected by the user
             w_bbox.classes = list(set(w_bbox.classes + list(result["label"])))
 
-
         if new_classes:
             classes = dataset.analyze.classes + new_classes
         else: 
@@ -202,6 +204,7 @@ class Labeler:
         right_arrow_btn.on_click(on_next)
         predict_btn.on_click(on_predict)
         plus_btn.on_click(on_add_class)
+        new_class_text.on_submit(on_add_class)
 
         #Returning the container will show the widgets 
         return pylabler
