@@ -4,20 +4,25 @@ from PIL import Image
 from pathlib import Path
 
 class Visualize:
+    def  __init__(self, dataset=None):
+        self.dataset = dataset
+
     """Functions to visualize inspect images and annotations."""
-    def ShowBoundingBoxes(self, dataset, img_id:int=0, img_filename:str="") -> Image:
+    def ShowBoundingBoxes(self, img_id:int=0, img_filename:str="") -> Image:
         """Enter a filename or index number and return the image with the bounding boxes drawn."""
 
+        ds = self.dataset
+
         #Handle cases where user enters image name in default field
         if type(img_id) == str:
             img_filename = img_id
 
         if img_filename == "": 
-            df_single_img_annots = dataset.df.loc[dataset.df.img_id == img_id]
+            df_single_img_annots = ds.df.loc[ds.df.img_id == img_id]
         else:
-            df_single_img_annots = dataset.df.loc[dataset.df.img_filename == img_filename]
+            df_single_img_annots = ds.df.loc[ds.df.img_filename == img_filename]
 
-        full_image_path = str(Path(dataset.path_to_annotations, df_single_img_annots.iloc[0].img_folder, df_single_img_annots.iloc[0].img_filename))
+        full_image_path = str(Path(ds.path_to_annotations, df_single_img_annots.iloc[0].img_folder, df_single_img_annots.iloc[0].img_filename))
         img = cv2.imread(str(full_image_path))
         img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
 
